# 2048-Wallpaper-Edition
2048 is a puzzle game that can be played right on your desktop background! Move the tiles around to create a tile with the value of 2048. Keep playing to see how high you can go.
